@@ -10,10 +10,10 @@ import sys
 
 import setuptools
 
-import setupmeta.versioning
-from setupmeta import listify, MetaDefs, project_path, relative_path, short, temp_resource, trace
+from setupmeta import listify, MetaDefs, project_path, readlines, relative_path, Requirements, short, trace
 from setupmeta.content import find_contents, load_contents, load_list, load_readme, resolved_paths
 from setupmeta.license import determined_license
+from setupmeta.versioning import project_scm, Versioning
 
 
 # Used to mark which key/values were provided explicitly in setup.py
@@ -32,23 +32,12 @@ RE_PY_VALUE = re.compile(r'^__([a-z_]+)__\s*=\s*u?[\'"](.+?)[\'"]\s*(#.+)?$')
 # Finds simple docstring entries like: author: Zoran Simic
 RE_DOC_VALUE = re.compile(r"^([a-z_]+)\s*[:=]\s*(.+?)(\s*#.+)?$")
 
+# Match PKG-INFO metadata, of the form: Some-Key: some value
+RE_PKG_KEY_VALUE = re.compile(r"^([-A-Za-z0-9_]+):\s?(.*)$")
+
 # Beautify short description
 RE_DESCRIPTION = re.compile(r"^[\W\s]*((([\w\-]+)\s*[:-])?\s*(.+))$", re.IGNORECASE)
 
-KNOWN_SECTIONS = set("abstract pinned indirect".split())
-
-
-def first_word(text):
-    """
-    :param str|None text: Text to extract first word from
-    :return str: Lower case of first word from 'text', if any
-    """
-    if text:
-        text = text.strip()
-    if not text:
-        return text
-    return text.split()[0].lower()
-
 
 def is_setup_py_path(path):
     """ Is 'path' pointing to a setup.py module? """
@@ -292,7 +281,10 @@ class SimpleModule(Settings):
 
 
 def get_pip():
-    """We can't assume pip is installed"""
+    """
+    Deprecated, see https://github.com/zsimic/setupmeta/issues/49
+    Left around for a while because some callers import this, they will have to adapt to pip 20.1+
+    """
     try:
         # pip >= 19.3
         from pip._internal.req import parse_requirements
@@ -321,58 +313,12 @@ def get_pip():
         return parse_requirements, PipSession
 
     except ImportError:
-        setupmeta.warn("Can't find PipSession, won't auto-fill requirements")
+        from setupmeta import warn
+
+        warn("Can't find PipSession, won't auto-fill requirements")
         return None, None
 
 
-def parse_requirements(requirements):
-    """Parse requirements with pip"""
-    # Note: we can't assume pip is installed
-    pip_parse_requirements, pip_session = get_pip()
-    if not pip_parse_requirements or not requirements:
-        return None, None
-
-    reqs = []
-    links = []
-    session = pip_session()
-    try:
-        if not isinstance(requirements, list):
-            # Parse given file path as-is (when not abstracting)
-            for ir in pip_parse_requirements(requirements, session=session):
-                if ir.link:
-                    if ir.name:
-                        reqs.append(ir.name)
-                    links.append(ir.link.url)
-                else:
-                    reqs.append(str(ir.req))
-
-            return reqs, links
-
-        with temp_resource(is_folder=False) as temp:
-            # Passed list is "complex reqs" that were not abstracted by the simple convention described here:
-            # https://github.com/zsimic/setupmeta/blob/master/docs/requirements.rst
-            with open(temp, "wt") as fh:
-                fh.write("\n".join(requirements))
-
-            for ir in pip_parse_requirements(temp, session=session):
-                if ir.link:
-                    if ir.name:
-                        reqs.append(ir.name)
-                    links.append(ir.link.url)
-                else:
-                    reqs.append(str(ir.req))
-
-    except Exception:
-        return None, None
-
-    return reqs, links
-
-
-def is_complex_requirement(line):
-    """Allows to save importing pip for very simple requirements.txt files"""
-    return line and (line.startswith("-") or ":" in line)
-
-
 def pythonified_name(name):
     if name:
         words = [s.strip() for s in RE_WORDS.split(name)]
@@ -391,60 +337,51 @@ class PackageInfo:
         "home_page": "url",
         "summary": "description",
     }
-    _list_types = ["classifiers", "long_description"]
+    _list_types = {"classifiers", "long_description"}
 
     def __init__(self, root):
         self.path = os.path.join(root, "PKG-INFO")
         self.info = {}
         self.name = None
-        self.dependency_links_txt = None
+        self.dependency_links = None
         self.entry_points_txt = None
         self.requires_txt = None
-        lines = load_contents(self.path)
+        lines = readlines(self.path)
         if not lines:
             return
 
         # Parse PKG-INFO when present
-        line_number = 0
         key = None
-        for line in lines.split("\n"):
-            line_number += 1
-            if line.startswith(" "):
-                self.info[key].append(line[8:])
-                continue
-
-            if ": " in line:
-                key, _, value = line.partition(": ")
-                key = self.canonical_key(key)
-                if key is None:
+        for line_number, line in enumerate(lines, start=1):
+            m = RE_PKG_KEY_VALUE.match(line)
+            if m:
+                key = m.group(1).lower().replace("-", "_")
+                key = self._canonical_names.get(key, key)
+                if key not in MetaDefs.all_fields:
                     continue
+
+                value = m.group(2)
                 if key in self._list_types:
                     if key not in self.info:
                         self.info[key] = []
+
                     self.info[key].append(value)
 
                 else:
                     self.info[key] = value
 
-                continue
+            elif key in self._list_types:
+                # Indented description applying to previous key
+                self.info[key].append(line[8:].rstrip())
 
-            setupmeta.trace("Unknown format line %s in %s: %s" % (line_number, self.path, line))
+            elif line.strip():
+                trace("Unknown format line %s in %s: %s" % (line_number, self.path, line))
 
         self.name = self.info.get("name")
         self.pythonified_name = pythonified_name(self.name)
         self.info["long_description"] = "\n".join(self.info.get("long_description", []))
         self.load_more_info(root)
 
-    def canonical_key(self, key):
-        """
-        :param str key: Key from PKG-INFO
-        :return str|None: Corresponding key for setuptools.setup(), if any
-        """
-        key = key.lower().replace("-", "_")
-        key = self._canonical_names.get(key, key)
-        if key in MetaDefs.all_fields:
-            return key
-
     def load_more_info(self, folder, depth=3):
         """
         :param str folder: Folder to scan for .egg-info file
@@ -456,7 +393,7 @@ class PackageInfo:
 
         path = os.path.join(folder, "%s.egg-info" % self.pythonified_name)
         if os.path.isdir(path):
-            self.dependency_links_txt = self.checked_file(path, "dependency_links.txt")
+            self.dependency_links = self.checked_file(path, "dependency_links.txt")
             self.entry_points_txt = self.checked_file(path, "entry_points.txt")
             self.requires_txt = self.checked_file(path, "requires.txt")
             return True
@@ -476,135 +413,6 @@ class PackageInfo:
             return path
 
 
-class RequirementsEntry:
-    """ Keeps track of where requirements came from """
-
-    def __init__(self, path, abstract=False):
-        """
-        :param str path: Path to req file
-        :param bool abstract: If True, abstract away simple pinning (applicable to install_requires only)
-        """
-        self.source = relative_path(path)
-        self.notes = {}
-        self.reqs = []
-        self.abstracted = []
-        self.untouched = []
-        self.ignored = []
-        self.links = None
-
-        if abstract:
-            self.parse_with_comments()
-
-        else:
-            reqs, links = parse_requirements(path)
-            if reqs:
-                self.reqs = reqs
-                self.links = links
-
-    def parse_with_comments(self):
-        # We're abstracting, allow comments to tweak how we do that
-        current_section = None
-        for line in load_list(self.source, comment=None):
-            if line.startswith("#"):
-                # Lines containing only a comment can start a "section", all requirements below this will respect that section
-                word = first_word(line[1:])
-                if word in KNOWN_SECTIONS:
-                    current_section = word
-                continue
-
-            line_section = current_section
-            note = None
-            if "# " in line:
-                # Trailing comments can direct us to treat that particular line in a certain way regarding pinning
-                i = line.index("# ")
-                word = first_word(line[i + 2:])
-                line = line[:i].strip()
-                if word in KNOWN_SECTIONS:
-                    line_section = word
-                    note = "'%s' stated on line" % word
-
-            if line_section == "indirect":
-                # 'indirect' means the pinning was done to satisfy some indirect dependency,
-                # but should not be considered as our project's dep
-                self.ignored.append("%s # %s" % (line, note or "indirect section"))
-                continue
-
-            if (not line_section or line_section == "abstract") and "==" in line:
-                # By default (or if in explicit 'abstract' section), trim away simple '==' pinning
-                i = line.index("==")
-                line = line[:i].strip()
-                if not note:
-                    if line_section:
-                        note = "in '%s' section" % line_section
-                    else:
-                        note = "abstracted by default"
-                self.abstracted.append("%s # %s" % (line, note))
-
-            elif line and (line[0].isalnum() or line.startswith("-e")):
-                # Count as untouched only actual deps (ignore flags such as -i)
-                if note:
-                    self.untouched.append("%s # %s" % (line, note))
-                else:
-                    self.untouched.append(line)
-
-            if note:
-                self.notes[line] = note or "abstract by default"
-
-            self.reqs.append(line)
-
-        if any(is_complex_requirement(line) for line in self.reqs):
-            reqs, links = parse_requirements(self.reqs)
-            if reqs:
-                self.reqs = reqs
-                self.links = links
-
-
-class Requirements:
-    """ Allows to auto-fill requires from requirements.txt """
-
-    def __init__(self, pkg_info):
-        """
-        :param PackageInfo pkg_info: PKG-INFO, when available
-        """
-        self.links_source = None
-        self.install = self.get_requirements(True, pkg_info.requires_txt, "requirements.txt", "pinned.txt")
-        self.test = self.get_requirements(
-            False,
-            "tests/requirements.txt",  # Preferred
-            "requirements-dev.txt",  # Also accept other common variations
-            "dev-requirements.txt",
-            "test-requirements.txt",
-            "requirements-test.txt",
-        )
-
-        if pkg_info.dependency_links_txt:
-            self.links_source = setupmeta.relative_path(pkg_info.dependency_links_txt)
-            self.links = load_list(pkg_info.dependency_links_txt)
-
-        else:
-            self.links = []
-            self.add_links(self.install)
-            self.add_links(self.test)
-
-    def add_links(self, entries):
-        if entries and entries.links:
-            if not self.links_source:
-                self.links_source = entries.source
-            for link in entries.links:
-                if link not in self.links:
-                    self.links.append(link)
-
-    @staticmethod
-    def get_requirements(abstract, *relative_paths):
-        """ Read old-school requirements.txt type file """
-        for path in relative_paths:
-            if path:
-                path = project_path(path)
-                if os.path.isfile(path):
-                    trace("found requirements: %s" % path)
-                    return RequirementsEntry(path, abstract=abstract)
-
-
 class SetupMeta(Settings):
     """ Find usable definitions throughout a project SetupPy SetupMeta """
 
@@ -626,7 +434,7 @@ class SetupMeta(Settings):
         self.pkg_info = PackageInfo(MetaDefs.project_dir)
         for key, value in self.pkg_info.info.items():
             if key in MetaDefs.all_fields:
-                self.add_definition(key, value, setupmeta.relative_path(self.pkg_info.path))
+                self.add_definition(key, value, relative_path(self.pkg_info.path))
 
         # Allow to auto-fill 'name' from setup.py's __title__, if any
         self.merge(SimpleModule("setup.py"))
@@ -682,8 +490,8 @@ class SetupMeta(Settings):
                     SimpleModule("src", package, "__init__.py"),
                 )
 
-        scm = scm or setupmeta.versioning.project_scm(MetaDefs.project_dir)
-        self.versioning = setupmeta.versioning.Versioning(self, scm)
+        scm = scm or project_scm(MetaDefs.project_dir)
+        self.versioning = Versioning(self, scm)
         self.versioning.auto_fill_version()
 
         self.fill_urls()
@@ -693,10 +501,10 @@ class SetupMeta(Settings):
         self.auto_adjust("maintainer", self.extract_email)
 
         self.requirements = Requirements(self.pkg_info)
-        self.auto_fill_requires("install", "install_requires")
-        self.auto_fill_requires("test", "tests_require")
-        if self.requirements.links:
-            self.auto_fill("dependency_links", self.requirements.links, self.requirements.links_source)
+        self.auto_fill_requires("install_requires")
+        self.auto_fill_requires("tests_require")
+        if self.requirements.dependency_links:
+            self.auto_fill("dependency_links", self.requirements.dependency_links, self.requirements.links_source)
 
         self.auto_fill_classifiers()
         self.auto_fill_entry_points()
@@ -801,7 +609,7 @@ class SetupMeta(Settings):
 
     def auto_fill_entry_points(self, key="entry_points"):
         if self.pkg_info.entry_points_txt:
-            self.add_definition(key, load_contents(self.pkg_info.entry_points_txt), setupmeta.relative_path(self.pkg_info.entry_points_txt))
+            self.add_definition(key, load_contents(self.pkg_info.entry_points_txt), relative_path(self.pkg_info.entry_points_txt))
         path = "%s.ini" % key
         self.add_definition(key, load_contents(path), path)
 
@@ -812,10 +620,10 @@ class SetupMeta(Settings):
         if short:
             self.auto_fill("license", short)
 
-    def auto_fill_requires(self, field, attr):
+    def auto_fill_requires(self, field):
         req = getattr(self.requirements, field)
         if req:
-            self.auto_fill(attr, req.reqs, req.source)
+            self.auto_fill(field, req.filled_requirements, req.source)
 
     @property
     def name(self):
